==> apache-drill-1.17.0-src.zip: apache-drill-1.17.0-src/contrib/storage-hive/core/src/main/java/org/apache/drill/exec/store/hive/writers/primitive/HiveDateWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.store.hive.writers.primitive;

import org.apache.drill.exec.vector.complex.writer.DateWriter;
import org.apache.hadoop.hive.serde2.objectinspector.primitive.DateObjectInspector;
import org.joda.time.DateTime;
import org.joda.time.DateTimeZone;

public class HiveDateWriter extends AbstractSingleValueWriter<DateObjectInspector, DateWriter> {

  public HiveDateWriter(DateObjectInspector inspector, DateWriter writer) {
    super(inspector, writer);
  }

  @Override
  public void write(Object value) {
    final java.sql.Date dateValue = inspector.getPrimitiveJavaObject(value);
    final DateTime date = new DateTime(dateValue.getTime()).withZoneRetainFields(DateTimeZone.UTC);
    writer.writeDate(date.getMillis());
  }

}

==> apache-drill-1.22.0-src.zip: apache-drill-1.22.0-src/contrib/storage-hive/core/src/main/java/org/apache/drill/exec/store/hive/writers/primitive/HiveDateWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.store.hive.writers.primitive;

import org.apache.drill.exec.vector.complex.writer.DateWriter;
import org.apache.hadoop.hive.serde2.objectinspector.PrimitiveObjectInspector;
import org.apache.hadoop.hive.serde2.objectinspector.primitive.PrimitiveObjectInspectorUtils;
import org.joda.time.DateTime;
import org.joda.time.DateTimeZone;

import java.sql.Date;

public class HiveDateWriter extends AbstractSingleValueWriter<PrimitiveObjectInspector, DateWriter> {

  public HiveDateWriter(PrimitiveObjectInspector inspector, DateWriter writer) {
    super(inspector, writer);
  }

  @Override
  public void write(Object value) {
    String dateString = PrimitiveObjectInspectorUtils.getString(value, inspector);
    long dateMillis = new DateTime(Date.valueOf(dateString).getTime())
        .withZoneRetainFields(DateTimeZone.UTC).getMillis();
    writer.writeDate(dateMillis);
  }

}
